==> pyatspi-0.1.5.tar.gz: pyatspi-0.1.5/pyatspi/interfaces.py <==
#Copyright (C) 2008 Codethink Ltd

#This library is free software; you can redistribute it and/or
#modify it under the terms of the GNU Lesser General Public
#License version 2 as published by the Free Software Foundation.

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#You should have received a copy of the GNU Lesser General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

ATSPI_ACCESSIBLE = 'org.freedesktop.atspi.Accessible'
ATSPI_ACTION = 'org.freedesktop.atspi.Action'
ATSPI_APPLICATION = 'org.freedesktop.atspi.Application'
ATSPI_COMPONENT = 'org.freedesktop.atspi.Component'
ATSPI_COLLECTION = 'org.freedesktop.atspi.Collection'
ATSPI_DESKTOP = 'org.freedesktop.atspi.Desktop'
ATSPI_DOCUMENT = 'org.freedesktop.atspi.Document'
ATSPI_EDITABLE_TEXT = 'org.freedesktop.atspi.EditableText'
ATSPI_HYPERLINK = 'org.freedesktop.atspi.Hyperlink'
ATSPI_HYPERTEXT = 'org.freedesktop.atspi.Hypertext'
ATSPI_IMAGE = 'org.freedesktop.atspi.Image'
ATSPI_LOGIN_HELPER = 'org.freedesktop.atspi.LoginHelper'
ATSPI_SELECTION = 'org.freedesktop.atspi.Selection'
ATSPI_SELECTOR = 'org.freedesktop.atspi.Selector'
ATSPI_STREAMABLE_CONTENT = 'org.freedesktop.atspi.Content'
ATSPI_TABLE = 'org.freedesktop.atspi.Table'
ATSPI_TEXT = 'org.freedesktop.atspi.Text'
ATSPI_VALUE = 'org.freedesktop.atspi.Value'

ATSPI_REGISTRY_INTERFACE = 'org.freedesktop.atspi.Registry'
ATSPI_REGISTRY_PATH = '/org/freedesktop/atspi/registry'
ATSPI_REGISTRY_NAME = 'org.freedesktop.atspi.Registry'

ATSPI_DESKTOP_PATH = '/org/freedesktop/atspi/accessible/desktop'

ATSPI_DEVICE_EVENT_LISTENER_INTERFACE = 'org.freedesktop.atspi.DeviceEventListener'
ATSPI_DEVICE_EVENT_CONTROLLER_INTERFACE = 'org.freedesktop.atspi.DeviceEventController'
ATSPI_DEVICE_EVENT_CONTROLLER_PATH = '/org/freedesktop/atspi/registry/deviceeventcontroller'
ATSPI_DEVICE_EVENT_CONTROLLER_NAME = 'org.freedesktop.atspi.Registry'

==> pyatspi-0.1.6.tar.gz: pyatspi-0.1.6/pyatspi/interfaces.py <==
#Copyright (C) 2008 Codethink Ltd

#This library is free software; you can redistribute it and/or
#modify it under the terms of the GNU Lesser General Public
#License version 2 as published by the Free Software Foundation.

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#You should have received a copy of the GNU Lesser General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

ATSPI_ACCESSIBLE = 'org.freedesktop.atspi.Accessible'
ATSPI_ACTION = 'org.freedesktop.atspi.Action'
ATSPI_APPLICATION = 'org.freedesktop.atspi.Application'
ATSPI_COMPONENT = 'org.freedesktop.atspi.Component'
ATSPI_COLLECTION = 'org.freedesktop.atspi.Collection'
ATSPI_DESKTOP = 'org.freedesktop.atspi.Desktop'
ATSPI_DOCUMENT = 'org.freedesktop.atspi.Document'
ATSPI_EDITABLE_TEXT = 'org.freedesktop.atspi.EditableText'
ATSPI_HYPERLINK = 'org.freedesktop.atspi.Hyperlink'
ATSPI_HYPERTEXT = 'org.freedesktop.atspi.Hypertext'
ATSPI_IMAGE = 'org.freedesktop.atspi.Image'
ATSPI_LOGIN_HELPER = 'org.freedesktop.atspi.LoginHelper'
ATSPI_SELECTION = 'org.freedesktop.atspi.Selection'
ATSPI_SELECTOR = 'org.freedesktop.atspi.Selector'
ATSPI_STREAMABLE_CONTENT = 'org.freedesktop.atspi.StreamableContent'
ATSPI_TABLE = 'org.freedesktop.atspi.Table'
ATSPI_TEXT = 'org.freedesktop.atspi.Text'
ATSPI_VALUE = 'org.freedesktop.atspi.Value'

ATSPI_REGISTRY_INTERFACE = 'org.freedesktop.atspi.Registry'
ATSPI_REGISTRY_PATH = '/org/freedesktop/atspi/registry'
ATSPI_REGISTRY_NAME = 'org.freedesktop.atspi.Registry'

ATSPI_ROOT_PATH = '/org/freedesktop/atspi/accessible/root'
ATSPI_NULL_PATH = '/org/freedesktop/atspi/null'

ATSPI_DEVICE_EVENT_LISTENER_INTERFACE = 'org.freedesktop.atspi.DeviceEventListener'
ATSPI_DEVICE_EVENT_CONTROLLER_INTERFACE = 'org.freedesktop.atspi.DeviceEventController'
ATSPI_DEVICE_EVENT_CONTROLLER_PATH = '/org/freedesktop/atspi/registry/deviceeventcontroller'
ATSPI_DEVICE_EVENT_CONTROLLER_NAME = 'org.freedesktop.atspi.Registry'
